searchNodes=[{"ref":"Zap.html","title":"Zap","type":"module","doc":"Native ZIP archive creation with chunked input and output. Erlang/OTP provides powerful the :zip and :zlib modules, but they can only create an archive all at once. That requires all of the data to be kept in memory or written to disk. What if you don&#39;t have enough space to keep the file in memory or on disk? With Zap you can add files one at a time while writing chunks of data at the same time. Examples Create a ZIP by adding a single entry at a time: iodata = Zap.new() |&gt; Zap.entry(&quot;a.txt&quot;, a_binary) |&gt; Zap.entry(&quot;b.txt&quot;, some_iodata) |&gt; Zap.entry(&quot;c.txt&quot;, more_iodata) |&gt; Zap.to_iodata() File.write!(&quot;archive.zip&quot;, iodata, [:binary, :raw]) Use into support from the Collectable protocol to build a ZIP dynamically: iodata = &quot;*.*&quot; |&gt; Path.wildcard() |&gt; Enum.map(fn path -&gt; {Path.basename(path), File.read!(path)} end) |&gt; Enum.into(Zap.new()) |&gt; Zap.to_iodata() File.write!(&quot;files.zip&quot;, iodata, [:binary, :raw]) Use Zap.into_stream/2 to incrementally build a ZIP by chunking files into an archive: one_mb = 1024 * 1024 write_fun = &amp;File.write!(&quot;streamed.zip&quot;, &amp;1, [:append, :binary, :raw]) file_list |&gt; Stream.map(fn path -&gt; {Path.basename(path), File.read!(path)} end) |&gt; Zap.into_stream(one_mb) |&gt; Stream.each(write_fun) |&gt; Stream.run() Glossary The entry and header bytes are composed based on the ZIP specification provided by PKWare. Some helpful terms that you may encounter in the function documentation: LFH (Local File Header) — Included before each file in the archive. The header contains details about the name and size of the entry. CDH (Central Directory Header) — The final bits of an archive, this contains summary information about the files contained within the archive."},{"ref":"Zap.html#bytes/1","title":"Zap.bytes/1","type":"function","doc":"Check the total number of un-flushed bytes available. Example iex&gt; Zap.bytes(Zap.new()) 0 iex&gt; Zap.new() ...&gt; |&gt; Zap.entry(&quot;a.txt&quot;, &quot;a&quot;) ...&gt; |&gt; Zap.bytes() 52 iex&gt; zap = Zap.new() ...&gt; zap = Zap.entry(zap, &quot;a.txt&quot;, &quot;a&quot;) ...&gt; {zap, _bytes} = Zap.flush(zap, :all) ...&gt; Zap.bytes(zap) 0"},{"ref":"Zap.html#entry/3","title":"Zap.entry/3","type":"function","doc":"Add a named entry to a zap struct. Example Zap.new() |&gt; Zap.entry(&quot;a.jpg&quot;, jpg_data) |&gt; Zap.entry(&quot;b.png&quot;, png_data)"},{"ref":"Zap.html#final/1","title":"Zap.final/1","type":"function","doc":"Generate the final CDH (Central Directory Header), required to complete an archive."},{"ref":"Zap.html#flush/2","title":"Zap.flush/2","type":"function","doc":"Flush a fixed number of bytes from the stored entries. Flushing is stateful, meaning the same data won&#39;t be flushed on successive calls. Example iex&gt; Zap.new() ...&gt; |&gt; Zap.entry(&quot;a.txt&quot;, &quot;aaaa&quot;) ...&gt; |&gt; Zap.entry(&quot;b.txt&quot;, &quot;bbbb&quot;) ...&gt; |&gt; Zap.flush() ...&gt; |&gt; elem(1) ...&gt; |&gt; IO.iodata_length() 110"},{"ref":"Zap.html#into_stream/2","title":"Zap.into_stream/2","type":"function","doc":"Stream an enumerable of name/data pairs into a zip structure and emit chunks of zip data. The chunked output will be at least the size of chunk_size, but they may be much larger. The last emitted chunk automatically includes the central directory header, the closing set of bytes. Example iex&gt; %{&quot;a.txt&quot; =&gt; &quot;aaaa&quot;, &quot;b.txt&quot; =&gt; &quot;bbbb&quot;} ...&gt; |&gt; Zap.into_stream(8) ...&gt; |&gt; Enum.to_list() ...&gt; |&gt; IO.iodata_to_binary() ...&gt; |&gt; :zip.table() ...&gt; |&gt; elem(0) :ok"},{"ref":"Zap.html#new/0","title":"Zap.new/0","type":"function","doc":"Initialize a new Zap struct. The struct is used to accumulate entries, which can then be flushed as parts of a zip file."},{"ref":"Zap.html#to_iodata/1","title":"Zap.to_iodata/1","type":"function","doc":"Output a complete iolist of data from a Zap struct. This is a convenient way of combining the output from flush/1 and final/1. Though the function is called to_iodata it also returns a zap struct because the struct is modified when it is flushed. Example iex&gt; Zap.new() ...&gt; |&gt; Zap.entry(&quot;a.txt&quot;, &quot;aaaa&quot;) ...&gt; |&gt; Zap.entry(&quot;b.txt&quot;, &quot;bbbb&quot;) ...&gt; |&gt; Zap.to_iodata() ...&gt; |&gt; IO.iodata_length() 248"},{"ref":"Zap.html#t:t/0","title":"Zap.t/0","type":"type","doc":""}]